@@ -167,8 +167,9 @@ assess_reference_loo <- function(reference, gen_start_col, reps = 50, mixsize =
 
       # we have to be a little careful about making the scaled likelihoods, because we can
       # run into some underflow issues.
-      logl_col_means <- colMeans(logL)
-      logl_swept <- sweep(logL, 2, logl_col_means)
+      logl_col_maxes <- apply(logL, 2, max)
+      logl_swept <- sweep(logL, 2, logl_col_maxes)
+
 
       SL <-  apply(exp(logl_swept), 2, function(y) y/sum(y))   # turn that into scaled likelihoods
 
